@@ -57,6 +57,7 @@ OWSRequest <- R6Class("OWSRequest",
     user = NULL,
     pwd = NULL,
     token = NULL,
+    auth_scheme = NULL,
 
     #GET
     #---------------------------------------------------------------
@@ -71,7 +72,7 @@ OWSRequest <- R6Class("OWSRequest",
       #headers
       headers <- c()
       if(!is.null(private$token)){
-        headers <- c(headers, "Authorization" = paste("Basic", private$token))
+        headers <- c(headers, "Authorization" = paste(private$auth_scheme, private$token))
       }
       
       r <- NULL
@@ -101,13 +102,20 @@ OWSRequest <- R6Class("OWSRequest",
     #---------------------------------------------------------------    
     POST = function(url, contentType = "text/xml", mimeType = "text/xml"){
       
+      #vendor params
+      geometa_validate <- if(!is.null(private$namedParams$geometa_validate)) as.logical(private$namedParams$geometa_validate) else TRUE
+      geometa_inspire <- if(!is.null(private$namedParams$geometa_inspire)) as.logical(private$namedParams$geometa_inspire) else FALSE
+      
       #XML encoding
-      outXML <- self$encode()
+      outXML <- self$encode(
+        geometa_validate = geometa_validate,
+        geometa_inspire = geometa_inspire
+      )
       
       #headers
       headers <- c("Accept" = "application/xml", "Content-Type" = contentType)
       if(!is.null(private$token)){
-        headers <- c(headers, "Authorization" = paste("Basic", private$token))
+        headers <- c(headers, "Authorization" = paste(private$auth_scheme, private$token))
       }
       
       #send request
@@ -146,7 +154,7 @@ OWSRequest <- R6Class("OWSRequest",
   public = list(
     #initialize
     initialize = function(op, type, url, request,
-                          user = NULL, pwd = NULL,
+                          user = NULL, pwd = NULL, token = NULL, 
                           namedParams = NULL, attrs = NULL,
                           contentType = "text/xml", mimeType = "text/xml",
                           logger = NULL, ...) {
@@ -158,12 +166,20 @@ OWSRequest <- R6Class("OWSRequest",
       private$contentType = contentType
       private$mimeType = mimeType
       
+      #authentication schemes
       if(!is.null(user) && !is.null(pwd)){
+        #Basic authentication (user/pwd) scheme
+        private$auth_scheme = "Basic"
         private$user = user
         private$pwd = pwd
         private$token = openssl::base64_encode(charToRaw(paste(user, pwd, sep=":")))
       }
-      
+      if(!is.null(token)){
+        #Token/Bearer authentication
+        private$auth_scheme = "Bearer"
+        private$token = token
+      }
+        
       vendorParams <- list(...)
       #if(!is.null(op)){
       #  for(param in names(vendorParams)){
@@ -185,7 +201,8 @@ OWSRequest <- R6Class("OWSRequest",
       #}
       vendorParams <- vendorParams[!sapply(vendorParams, is.null)]
       vendorParams <- lapply(vendorParams, curl::curl_escape)
-      namedParams <- c(namedParams, vendorParams)
+      print(vendorParams)
+      private$namedParams <- c(private$namedParams, vendorParams)
     },
     
     #execute
