@@ -8,7 +8,7 @@
 #'
 #' @section Methods:
 #' \describe{
-#'  \item{\code{new(op, url, version, typeName)}}{
+#'  \item{\code{new(op, url, version, typeName, logger, ...)}}{
 #'    This method is used to instantiate a WFSDescribeFeatureType object
 #'  }
 #' }
@@ -23,10 +23,11 @@ WFSDescribeFeatureType <- R6Class("WFSDescribeFeatureType",
     name = "DescribeFeatureType"
   ),
   public = list(
-    initialize = function(op, url, version, typeName, ...) {
+    initialize = function(op, url, version, typeName, logger = NULL, ...) {
       namedParams <- list(service = "WFS", version = version, typeName = typeName)
       super$initialize(op, "GET", url, request = private$name,
-                       namedParams = namedParams, mimeType = "text/xml", ...)
+                       namedParams = namedParams, mimeType = "text/xml", logger = logger,
+                       ...)
       self$execute()
     }
   )
